# nesse
Nab Event Shape SImulation Effort (NESSE) is a python based solid state detector simulation developed for the Nab experiment. 


### Dependencies
Please insure the following dependencies are installed prior to using nessie.

- Cython==0.29.32
- uproot==4.3.7
- joblib==1.2.0
- ipywidgets==8.0.4 (for using with jupyter notebook)


### Install
To use nesse git clone and append the path to the nesse src directory like below:
```
import sys
sys.path.append(path_to_nesse+"/src/")
import nesse
```

Please see the tutorial notebook for more instruction on how to use nesse. 
